import { pageTypeMap } from '@temp/blog/pageType';
import { useRouter } from 'vue-router';
import { useRouteLocale, usePageFrontmatter } from '@vuepress/client';
import { computed, ref } from 'vue';
import { resolveRouteWithRedirect } from './../utils';
export const blogPageTypeMap = ref(pageTypeMap);
/**
 * page type hooks
 * @param key
 * @returns
 */
export const useBlogPageType = (key = '') => {
    const router = useRouter();
    const routerLocale = useRouteLocale();
    return computed(() => {
        const mapKey = key || usePageFrontmatter().value.blog?.key || '';
        const routes = router.getRoutes();
        const configMap = blogPageTypeMap.value[mapKey][routerLocale.value];
        const result = {
            path: configMap.path,
            items: []
        };
        for (const pageKey of configMap.keys) {
            const route = routes.find(({ name }) => name === pageKey);
            if (route) {
                const finalRoute = resolveRouteWithRedirect(router, route.path);
                result.items.push({
                    path: finalRoute.path,
                    info: BLOG_META_SCOPE === '' ? finalRoute.meta : finalRoute.meta[BLOG_META_SCOPE]
                });
            }
        }
        return result;
    });
};
// @ts-ignore
if (import.meta.webpack || import.meta.hot) {
    __VUE_HMR_RUNTIME__.updateBlogType = (map) => {
        blogPageTypeMap.value = map;
    };
}
//# sourceMappingURL=usePageType.js.map