"use strict";
/**
 * 目录分类器 根据目录管理文章
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.prepareDirectories = void 0;
const vuepress_shared_1 = require("@mr-huang/vuepress-shared");
const utils_1 = require("../utils");
/**
 * 开发时热更新
 */
const HMR_CODE = `
if (import.meta.webpackHot) {
  import.meta.webpackHot.accept()
  if (__VUE_HMR_RUNTIME__.updateBlogType) {
    __VUE_HMR_RUNTIME__.updateBlogType(pageTypeMap)
  }
}

if (import.meta.hot) {
  import.meta.hot.accept(({ pageTypeMap }) => {
    __VUE_HMR_RUNTIME__.updateBlogType(pageTypeMap)
  })
}
`;
/**
 * filter
 * @param param0 。
 * @param indexPath
 * @param dirname
 * @returns
 */
const filter = ({ filePathRelative }, indexPath, dirname) => {
    const regex = new RegExp(`^${dirname}/page/`);
    return (filePathRelative &&
        filePathRelative !== indexPath &&
        filePathRelative.startsWith(`${dirname}/`));
};
/**
 * 创建分类器
 * @param app
 * @param options
 * @param pages
 */
const createDirectoriesClassifier = (app, directoryClassifiers, pages) => {
    return directoryClassifiers.map(async (classifier) => {
        /**
         * 1. Directory-based classification
         */
        const { key, dirname, path: indexPath = `/${classifier.key}/`, layout: indexLayout = 'Layout', frontmatter, itemLayout = 'Layout', itemPermalink = '/:year/:month/:day/:slug', title = (0, vuepress_shared_1.upperFirstChar)(classifier.key) } = classifier;
        const finalExtraPages = [];
        for (const routeLocale in pages) {
            pages[routeLocale].filter(page => filter(page, indexPath, dirname)).map(page => {
                if (page.path === `/${dirname}/`) {
                    // 首页
                    page.frontmatter = {
                        ...page.frontmatter,
                        layout: indexLayout,
                        ...frontmatter
                    };
                }
            });
        }
        // console.log('===================', pages)
        // key 不对或者不存在
        if (typeof key !== 'string' || !key) {
            utils_1.logger.error(`Invalid 'key' option ${key} in directory classifier.`);
            return null;
        }
        if (app.env.isDebug)
            utils_1.logger.info('====');
        return true;
    });
};
const prepareDirectories = (app, options, pages) => {
    const { directoryClassifier = [] } = options;
    return Promise.all(createDirectoriesClassifier(app, directoryClassifier, pages)).then(async () => {
        // console.log(JSON.stringify(result, null, 2))
    });
};
exports.prepareDirectories = prepareDirectories;
//# sourceMappingURL=prepareDirectories.js.map